@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="sq">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
 <context>
     <name>MainWindow</name>
     <message>
@@ -359,4 +357,4 @@ start the process</extracomment>
         <translation>Këtë program duhet ta xhironi si përdorues i thjeshtë.</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
